@@ -5,7 +5,7 @@
 
 // These variables are used to locate the python module files since we cannot
 // reply on the executable path to locate python module files.
-#define PARAVIEW_BINARY_DIR "C:/M/B/src/build-CLANGARM64"
+#define PARAVIEW_BINARY_DIR "C:/W/B/src/build-CLANGARM64"
 #define PARAVIEW_INSTALL_DIR "/clangarm64"
 
 #endif
