@@ -33,10 +33,16 @@
 #  define VTKREMOTINGEXPORT_DEPRECATED_NO_EXPORT VTKREMOTINGEXPORT_NO_EXPORT VTKREMOTINGEXPORT_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKREMOTINGEXPORT_NO_DEPRECATED
 #    define VTKREMOTINGEXPORT_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkRemotingExportModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKREMOTINGEXPORT_EXPORT_H */
